==> skill-core-0.0.5-sources.jar: com/ptteng/sca/common/skill/client/TaskSkillRelationSCAClient.java <==
/**
 * 
 */
package com.ptteng.sca.common.skill.client;

import java.util.List;
import java.util.Map;

import com.ptteng.common.skill.model.TaskSkillRelation;
import com.ptteng.common.skill.service.TaskSkillRelationService;
import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;

public class TaskSkillRelationSCAClient implements TaskSkillRelationService {

    private TaskSkillRelationService taskSkillRelationService;

	public TaskSkillRelationService getTaskSkillRelationService() {
		return taskSkillRelationService;
	}
	
	
	public void setTaskSkillRelationService(TaskSkillRelationService taskSkillRelationService) {
		this.taskSkillRelationService =taskSkillRelationService;
	}
	
	
			   
		@Override
		public Long insert(TaskSkillRelation taskSkillRelation)throws ServiceException, ServiceDaoException{
		
		return taskSkillRelationService.insert(taskSkillRelation);
		          
		
		}	
		  
    	   
		@Override
		public List<TaskSkillRelation> insertList(List<TaskSkillRelation> taskSkillRelationList)throws ServiceException, ServiceDaoException{
		
		return taskSkillRelationService.insertList(taskSkillRelationList);
		          
		
		}	
		  
    	   
		@Override
		public boolean delete(Long id)throws ServiceException, ServiceDaoException{
		
		return taskSkillRelationService.delete(id);
		          
		
		}	
		  
    	   
		@Override
		public boolean update(TaskSkillRelation taskSkillRelation)throws ServiceException, ServiceDaoException{
		
		return taskSkillRelationService.update(taskSkillRelation);
		          
		
		}	
		  
    	   
		@Override
		public boolean updateList(List<TaskSkillRelation> taskSkillRelationList)throws ServiceException, ServiceDaoException{
		
		return taskSkillRelationService.updateList(taskSkillRelationList);
		          
		
		}	
		  
    	   
		@Override
		public TaskSkillRelation getObjectById(Long id)throws ServiceException, ServiceDaoException{
		
		return taskSkillRelationService.getObjectById(id);
		          
		
		}	
		  
    	   
		@Override
		public List<TaskSkillRelation> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException{
		
		return taskSkillRelationService.getObjectsByIds(ids);
		          
		
		}	
		  
    	
	
	
	
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Long  getTaskSkillRelationIdByTidAndSid(Long Tid,Long sid)throws ServiceException, ServiceDaoException{
		
		return taskSkillRelationService.getTaskSkillRelationIdByTidAndSid(Tid,sid);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getTaskSkillRelationIdsBySid(Long sid,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return taskSkillRelationService.getTaskSkillRelationIdsBySid(sid,start,limit);
	
	
	}

	@Override
	public List<Long> getSidsByOid(Long oid, Integer start, Integer limit) throws ServiceException, ServiceDaoException {
		return taskSkillRelationService.getSidsByOid(oid,start,limit);
	}


	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getTaskSkillRelationIdsByTid(Long tid,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return taskSkillRelationService.getTaskSkillRelationIdsByTid(tid,start,limit);
	
	
	}

	@Override
	public List<Long> getSkillIdsByTid(Long tid, Integer start, Integer limit) throws ServiceException, ServiceDaoException {
		return taskSkillRelationService.getSkillIdsByTid(tid,start,limit);
	}


	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countTaskSkillRelationIdsBySid(Long sid)throws ServiceException, ServiceDaoException{
		
		return taskSkillRelationService.countTaskSkillRelationIdsBySid(sid);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countTaskSkillRelationIdsByTid(Long tid)throws ServiceException, ServiceDaoException{
		
		return taskSkillRelationService.countTaskSkillRelationIdsByTid(tid);
	
	
	}
	
		
	
		@Override
	public List<Long> getTaskSkillRelationIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return taskSkillRelationService.getTaskSkillRelationIds(start, limit);
	}

	@Override
	public Integer countTaskSkillRelationIds() throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return taskSkillRelationService.countTaskSkillRelationIds();
	}
	
	
	@Override
	public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return taskSkillRelationService.getIdsByDynamicCondition(clz, conditions, start, limit);
	}


	@Override
	public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return taskSkillRelationService.fakeDelete(clz, id);
	}
	
	
	
	@Override
	public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
		   taskSkillRelationService.deleteList(clz, ids);
		
	}


 
}

==> skill-core-30.0.5-sources.jar: com/ptteng/sca/common/skill/client/TaskSkillRelationSCAClient.java <==
/**
 * 
 */
package com.ptteng.sca.common.skill.client;

import java.util.List;
import java.util.Map;

import com.ptteng.common.skill.model.TaskSkillRelation;
import com.ptteng.common.skill.service.TaskSkillRelationService;
import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;

public class TaskSkillRelationSCAClient implements TaskSkillRelationService {

    private TaskSkillRelationService taskSkillRelationService;

	public TaskSkillRelationService getTaskSkillRelationService() {
		return taskSkillRelationService;
	}
	
	
	public void setTaskSkillRelationService(TaskSkillRelationService taskSkillRelationService) {
		this.taskSkillRelationService =taskSkillRelationService;
	}
	
	
			   
		@Override
		public Long insert(TaskSkillRelation taskSkillRelation)throws ServiceException, ServiceDaoException{
		
		return taskSkillRelationService.insert(taskSkillRelation);
		          
		
		}	
		  
    	   
		@Override
		public List<TaskSkillRelation> insertList(List<TaskSkillRelation> taskSkillRelationList)throws ServiceException, ServiceDaoException{
		
		return taskSkillRelationService.insertList(taskSkillRelationList);
		          
		
		}	
		  
    	   
		@Override
		public boolean delete(Long id)throws ServiceException, ServiceDaoException{
		
		return taskSkillRelationService.delete(id);
		          
		
		}	
		  
    	   
		@Override
		public boolean update(TaskSkillRelation taskSkillRelation)throws ServiceException, ServiceDaoException{
		
		return taskSkillRelationService.update(taskSkillRelation);
		          
		
		}	
		  
    	   
		@Override
		public boolean updateList(List<TaskSkillRelation> taskSkillRelationList)throws ServiceException, ServiceDaoException{
		
		return taskSkillRelationService.updateList(taskSkillRelationList);
		          
		
		}	
		  
    	   
		@Override
		public TaskSkillRelation getObjectById(Long id)throws ServiceException, ServiceDaoException{
		
		return taskSkillRelationService.getObjectById(id);
		          
		
		}	
		  
    	   
		@Override
		public List<TaskSkillRelation> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException{
		
		return taskSkillRelationService.getObjectsByIds(ids);
		          
		
		}	
		  
    	
	
	
	
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Long  getTaskSkillRelationIdByTidAndSid(Long Tid,Long sid)throws ServiceException, ServiceDaoException{
		
		return taskSkillRelationService.getTaskSkillRelationIdByTidAndSid(Tid,sid);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getTaskSkillRelationIdsBySid(Long sid,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return taskSkillRelationService.getTaskSkillRelationIdsBySid(sid,start,limit);
	
	
	}

	@Override
	public List<Long> getSidsByOid(Long oid, Integer start, Integer limit) throws ServiceException, ServiceDaoException {
		return taskSkillRelationService.getSidsByOid(oid,start,limit);
	}


	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getTaskSkillRelationIdsByTid(Long tid,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return taskSkillRelationService.getTaskSkillRelationIdsByTid(tid,start,limit);
	
	
	}

	@Override
	public List<Long> getSkillIdsByTid(Long tid, Integer start, Integer limit) throws ServiceException, ServiceDaoException {
		return taskSkillRelationService.getSkillIdsByTid(tid,start,limit);
	}


	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countTaskSkillRelationIdsBySid(Long sid)throws ServiceException, ServiceDaoException{
		
		return taskSkillRelationService.countTaskSkillRelationIdsBySid(sid);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countTaskSkillRelationIdsByTid(Long tid)throws ServiceException, ServiceDaoException{
		
		return taskSkillRelationService.countTaskSkillRelationIdsByTid(tid);
	
	
	}
	
		
	
		@Override
	public List<Long> getTaskSkillRelationIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return taskSkillRelationService.getTaskSkillRelationIds(start, limit);
	}

	@Override
	public Integer countTaskSkillRelationIds() throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return taskSkillRelationService.countTaskSkillRelationIds();
	}
	
	
	@Override
	public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return taskSkillRelationService.getIdsByDynamicCondition(clz, conditions, start, limit);
	}

	@Override
	public Object getObjectByDynamicCondition(Class aClass, Map<String, Object> map, Integer integer, Integer integer1) throws ServiceException, ServiceDaoException {
		return taskSkillRelationService.getObjectByDynamicCondition(aClass, map, integer, integer1);
	}


	@Override
	public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return taskSkillRelationService.fakeDelete(clz, id);
	}
	
	
	
	@Override
	public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
		   taskSkillRelationService.deleteList(clz, ids);
		
	}


 
}
